gopbt

package module
v0.0.0-...-9b4ed5f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 12, 2023 License: MIT Imports: 6 Imported by: 0

README

GoPBT (WIP)

GoPBT is a library that aims to provide type-safe, reliable and easy-to-use property based testing tools for Go deveolpers. (WIP, detailed documentations will be generated on tagged releases)

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetGen

func SetGen[T any](s *Session, g gen.Generator[T])

Types

type FunctionReturningBool

type FunctionReturningBool = any

type Session

type Session struct {

	// SupportAdhocGenerators means that the program runtime can create generators for types that don't have any generators available
	SupportAdhocGenerators bool
	// contains filtered or unexported fields
}

func NewSession

func NewSession() *Session

func NewSessionWithPrimitives

func NewSessionWithPrimitives() *Session

func (*Session) Check

func (s *Session) Check(f FunctionReturningBool, conf *quick.Config) error

Directories

Path Synopsis

Jump to